Documentation
¶
Index ¶
- type Elastigroup
- func (r *Elastigroup) DesiredCapacity() *pulumi.IntOutput
- func (r *Elastigroup) HealthCheck() *pulumi.Output
- func (r *Elastigroup) ID() *pulumi.IDOutput
- func (r *Elastigroup) Images() *pulumi.ArrayOutput
- func (r *Elastigroup) LoadBalancers() *pulumi.ArrayOutput
- func (r *Elastigroup) Login() *pulumi.Output
- func (r *Elastigroup) LowPrioritySizes() *pulumi.ArrayOutput
- func (r *Elastigroup) MaxSize() *pulumi.IntOutput
- func (r *Elastigroup) MinSize() *pulumi.IntOutput
- func (r *Elastigroup) Name() *pulumi.StringOutput
- func (r *Elastigroup) Network() *pulumi.Output
- func (r *Elastigroup) OdSizes() *pulumi.ArrayOutput
- func (r *Elastigroup) Product() *pulumi.StringOutput
- func (r *Elastigroup) Region() *pulumi.StringOutput
- func (r *Elastigroup) ResourceGroupName() *pulumi.StringOutput
- func (r *Elastigroup) ScheduledTasks() *pulumi.ArrayOutput
- func (r *Elastigroup) Strategy() *pulumi.Output
- func (r *Elastigroup) URN() *pulumi.URNOutput
- func (r *Elastigroup) UserData() *pulumi.StringOutput
- type ElastigroupArgs
- type ElastigroupState
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Elastigroup ¶
type Elastigroup struct {
// contains filtered or unexported fields
}
Provides a Spotinst elastigroup Azure resource.
func GetElastigroup ¶
func GetElastigroup(ctx *pulumi.Context, name string, id pulumi.ID, state *ElastigroupState, opts ...pulumi.ResourceOpt) (*Elastigroup, error)
GetElastigroup gets an existing Elastigroup resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewElastigroup ¶
func NewElastigroup(ctx *pulumi.Context, name string, args *ElastigroupArgs, opts ...pulumi.ResourceOpt) (*Elastigroup, error)
NewElastigroup registers a new resource with the given unique name, arguments, and options.
func (*Elastigroup) DesiredCapacity ¶
func (r *Elastigroup) DesiredCapacity() *pulumi.IntOutput
The desired number of instances the group should have at any time.
func (*Elastigroup) HealthCheck ¶
func (r *Elastigroup) HealthCheck() *pulumi.Output
Describes the health check configuration.
func (*Elastigroup) ID ¶
func (r *Elastigroup) ID() *pulumi.IDOutput
ID is this resource's unique identifier assigned by its provider.
func (*Elastigroup) Images ¶
func (r *Elastigroup) Images() *pulumi.ArrayOutput
Image of a VM. An image is a template for creating new VMs. Choose from Azure image catalogue (marketplace) or use a custom image.
func (*Elastigroup) LoadBalancers ¶
func (r *Elastigroup) LoadBalancers() *pulumi.ArrayOutput
Describes a set of one or more classic load balancer target groups and/or Multai load balancer target sets.
func (*Elastigroup) Login ¶
func (r *Elastigroup) Login() *pulumi.Output
Describes the login configuration.
func (*Elastigroup) LowPrioritySizes ¶
func (r *Elastigroup) LowPrioritySizes() *pulumi.ArrayOutput
Available Low-Priority sizes.
func (*Elastigroup) MaxSize ¶
func (r *Elastigroup) MaxSize() *pulumi.IntOutput
The maximum number of instances the group should have at any time.
func (*Elastigroup) MinSize ¶
func (r *Elastigroup) MinSize() *pulumi.IntOutput
The minimum number of instances the group should have at any time.
func (*Elastigroup) Network ¶
func (r *Elastigroup) Network() *pulumi.Output
Defines the Virtual Network and Subnet for your Elastigroup.
func (*Elastigroup) OdSizes ¶
func (r *Elastigroup) OdSizes() *pulumi.ArrayOutput
Available On-Demand sizes
func (*Elastigroup) Product ¶
func (r *Elastigroup) Product() *pulumi.StringOutput
Operation system type. Valid values: `"Linux"`, `"Windows"`.
func (*Elastigroup) Region ¶
func (r *Elastigroup) Region() *pulumi.StringOutput
The region your Azure group will be created in.
func (*Elastigroup) ResourceGroupName ¶
func (r *Elastigroup) ResourceGroupName() *pulumi.StringOutput
Vnet Resource Group Name.
func (*Elastigroup) ScheduledTasks ¶
func (r *Elastigroup) ScheduledTasks() *pulumi.ArrayOutput
Describes the configuration of one or more scheduled tasks.
func (*Elastigroup) Strategy ¶
func (r *Elastigroup) Strategy() *pulumi.Output
Describes the deployment strategy.
func (*Elastigroup) URN ¶
func (r *Elastigroup) URN() *pulumi.URNOutput
URN is this resource's unique name assigned by Pulumi.
func (*Elastigroup) UserData ¶
func (r *Elastigroup) UserData() *pulumi.StringOutput
Base64-encoded MIME user data to make available to the instances.
type ElastigroupArgs ¶
type ElastigroupArgs struct {
// The desired number of instances the group should have at any time.
DesiredCapacity interface{}
// Describes the health check configuration.
HealthCheck interface{}
// Image of a VM. An image is a template for creating new VMs. Choose from Azure image catalogue (marketplace) or use a custom image.
Images interface{}
// Describes a set of one or more classic load balancer target groups and/or Multai load balancer target sets.
LoadBalancers interface{}
// Describes the login configuration.
Login interface{}
// Available Low-Priority sizes.
LowPrioritySizes interface{}
// The maximum number of instances the group should have at any time.
MaxSize interface{}
// The minimum number of instances the group should have at any time.
MinSize interface{}
// The group name.
Name interface{}
// Defines the Virtual Network and Subnet for your Elastigroup.
Network interface{}
// Available On-Demand sizes
OdSizes interface{}
// Operation system type. Valid values: `"Linux"`, `"Windows"`.
Product interface{}
// The region your Azure group will be created in.
Region interface{}
// Vnet Resource Group Name.
ResourceGroupName interface{}
// Describes the configuration of one or more scheduled tasks.
ScheduledTasks interface{}
// Describes the deployment strategy.
Strategy interface{}
// Base64-encoded MIME user data to make available to the instances.
UserData interface{}
}
The set of arguments for constructing a Elastigroup resource.
type ElastigroupState ¶
type ElastigroupState struct {
// The desired number of instances the group should have at any time.
DesiredCapacity interface{}
// Describes the health check configuration.
HealthCheck interface{}
// Image of a VM. An image is a template for creating new VMs. Choose from Azure image catalogue (marketplace) or use a custom image.
Images interface{}
// Describes a set of one or more classic load balancer target groups and/or Multai load balancer target sets.
LoadBalancers interface{}
// Describes the login configuration.
Login interface{}
// Available Low-Priority sizes.
LowPrioritySizes interface{}
// The maximum number of instances the group should have at any time.
MaxSize interface{}
// The minimum number of instances the group should have at any time.
MinSize interface{}
// The group name.
Name interface{}
// Defines the Virtual Network and Subnet for your Elastigroup.
Network interface{}
// Available On-Demand sizes
OdSizes interface{}
// Operation system type. Valid values: `"Linux"`, `"Windows"`.
Product interface{}
// The region your Azure group will be created in.
Region interface{}
// Vnet Resource Group Name.
ResourceGroupName interface{}
// Describes the configuration of one or more scheduled tasks.
ScheduledTasks interface{}
// Describes the deployment strategy.
Strategy interface{}
// Base64-encoded MIME user data to make available to the instances.
UserData interface{}
}
Input properties used for looking up and filtering Elastigroup resources.