Documentation
¶
Index ¶
- type Elastigroup
- func (r *Elastigroup) ClusterId() *pulumi.StringOutput
- func (r *Elastigroup) ClusterZoneName() *pulumi.StringOutput
- func (r *Elastigroup) DesiredCapacity() *pulumi.IntOutput
- func (r *Elastigroup) ID() *pulumi.IDOutput
- func (r *Elastigroup) InstanceTypesOndemand() *pulumi.StringOutput
- func (r *Elastigroup) InstanceTypesPreemptibles() *pulumi.ArrayOutput
- func (r *Elastigroup) MaxSize() *pulumi.IntOutput
- func (r *Elastigroup) MinSize() *pulumi.IntOutput
- func (r *Elastigroup) Name() *pulumi.StringOutput
- func (r *Elastigroup) NodeImage() *pulumi.StringOutput
- func (r *Elastigroup) PreemptiblePercentage() *pulumi.IntOutput
- func (r *Elastigroup) URN() *pulumi.URNOutput
- type ElastigroupArgs
- type ElastigroupState
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Elastigroup ¶
type Elastigroup struct {
// contains filtered or unexported fields
}
Provides a Spotinst elastigroup GKE resource.
func GetElastigroup ¶
func GetElastigroup(ctx *pulumi.Context, name string, id pulumi.ID, state *ElastigroupState, opts ...pulumi.ResourceOpt) (*Elastigroup, error)
GetElastigroup gets an existing Elastigroup resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).
func NewElastigroup ¶
func NewElastigroup(ctx *pulumi.Context, name string, args *ElastigroupArgs, opts ...pulumi.ResourceOpt) (*Elastigroup, error)
NewElastigroup registers a new resource with the given unique name, arguments, and options.
func (*Elastigroup) ClusterId ¶
func (r *Elastigroup) ClusterId() *pulumi.StringOutput
The name of the GKE cluster you wish to import.
func (*Elastigroup) ClusterZoneName ¶
func (r *Elastigroup) ClusterZoneName() *pulumi.StringOutput
The zone where the cluster is hosted.
func (*Elastigroup) DesiredCapacity ¶
func (r *Elastigroup) DesiredCapacity() *pulumi.IntOutput
The desired number of instances the group should have at any time.
func (*Elastigroup) ID ¶
func (r *Elastigroup) ID() *pulumi.IDOutput
ID is this resource's unique identifier assigned by its provider.
func (*Elastigroup) InstanceTypesOndemand ¶
func (r *Elastigroup) InstanceTypesOndemand() *pulumi.StringOutput
func (*Elastigroup) InstanceTypesPreemptibles ¶
func (r *Elastigroup) InstanceTypesPreemptibles() *pulumi.ArrayOutput
The preemptible VMs instance type. To maximize cost savings and market availability, select as many types as possible. Required if instance_types_on_demand is not set.
func (*Elastigroup) MaxSize ¶
func (r *Elastigroup) MaxSize() *pulumi.IntOutput
The maximum number of instances the group should have at any time.
func (*Elastigroup) MinSize ¶
func (r *Elastigroup) MinSize() *pulumi.IntOutput
The minimum number of instances the group should have at any time.
func (*Elastigroup) NodeImage ¶
func (r *Elastigroup) NodeImage() *pulumi.StringOutput
The image that will be used for the node VMs. Possible values: COS, UBUNTU.
func (*Elastigroup) PreemptiblePercentage ¶
func (r *Elastigroup) PreemptiblePercentage() *pulumi.IntOutput
The percentage of preemptible VMs that would spin up from the desired capacity (range: 0-100).
func (*Elastigroup) URN ¶
func (r *Elastigroup) URN() *pulumi.URNOutput
URN is this resource's unique name assigned by Pulumi.
type ElastigroupArgs ¶
type ElastigroupArgs struct {
// The name of the GKE cluster you wish to import.
ClusterId interface{}
// The zone where the cluster is hosted.
ClusterZoneName interface{}
// The desired number of instances the group should have at any time.
DesiredCapacity interface{}
InstanceTypesOndemand interface{}
// The preemptible VMs instance type. To maximize cost savings and market availability, select as many types as possible. Required if instance_types_on_demand is not set.
InstanceTypesPreemptibles interface{}
// The maximum number of instances the group should have at any time.
MaxSize interface{}
// The minimum number of instances the group should have at any time.
MinSize interface{}
// The group name.
Name interface{}
// The image that will be used for the node VMs. Possible values: COS, UBUNTU.
NodeImage interface{}
// The percentage of preemptible VMs that would spin up from the desired capacity (range: 0-100).
PreemptiblePercentage interface{}
}
The set of arguments for constructing a Elastigroup resource.
type ElastigroupState ¶
type ElastigroupState struct {
// The name of the GKE cluster you wish to import.
ClusterId interface{}
// The zone where the cluster is hosted.
ClusterZoneName interface{}
// The desired number of instances the group should have at any time.
DesiredCapacity interface{}
InstanceTypesOndemand interface{}
// The preemptible VMs instance type. To maximize cost savings and market availability, select as many types as possible. Required if instance_types_on_demand is not set.
InstanceTypesPreemptibles interface{}
// The maximum number of instances the group should have at any time.
MaxSize interface{}
// The minimum number of instances the group should have at any time.
MinSize interface{}
// The group name.
Name interface{}
// The image that will be used for the node VMs. Possible values: COS, UBUNTU.
NodeImage interface{}
// The percentage of preemptible VMs that would spin up from the desired capacity (range: 0-100).
PreemptiblePercentage interface{}
}
Input properties used for looking up and filtering Elastigroup resources.